@@ -16,17 +16,17 @@
 import os
 import sys
 
-sys.path.insert(0, os.path.abspath('..'))
+sys.path.insert(0, os.path.abspath(".."))
 
 
 # -- Project information -----------------------------------------------------
 
-project = 'JSON Schema and CSV Codelists'
-copyright = '2020, Open Contracting Partnership and Open Data Services Co-operative Limited'
-author = 'Open Contracting Partnership and Open Data Services Co-operative Limited'
+project = "JSON Schema and CSV Codelists"
+copyright = "2020, Open Contracting Partnership and Open Data Services Co-operative Limited"
+author = "Open Contracting Partnership and Open Data Services Co-operative Limited"
 
 # The short X.Y version
-version = '0.0.7'
+version = "0.0.9"
 # The full version, including alpha/beta/rc tags
 release = version
 
@@ -37,17 +37,18 @@ release = version
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'sphinx.ext.autodoc',
-    'sphinx.ext.viewcode',
+    "sphinx.ext.autodoc",
+    "sphinx.ext.intersphinx",
+    "sphinx.ext.viewcode",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 
 # -- Options for HTML output -------------------------------------------------
@@ -55,7 +56,7 @@ exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'default'
+html_theme = "furo"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -65,17 +66,13 @@ html_static_path = []
 
 # -- Extension configuration -------------------------------------------------
 
-# Needed for ReadTheDocs (Sphinx 1.8).
-master_doc = 'index'
-
 autodoc_default_options = {
-    'members': None,
+    "members": None,
+    "member-order": "bysource",
 }
-autodoc_member_order = 'bysource'
+autodoc_typehints = "description"
+autodoc_type_aliases = {}
 
-on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-
-if not on_rtd:  # only import and set the theme if we're building docs locally
-    import sphinx_rtd_theme
-    html_theme = 'sphinx_rtd_theme'
-    html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
+intersphinx_mapping = {
+    "python": ("https://docs.python.org/3", None),
+}
