@@ -1,6 +1,7 @@
 import contextlib
 import json
 import os
+import warnings
 
 import pytest
 from jsonref import JsonRef
@@ -128,6 +129,16 @@ def test_validate_deep_properties():
     assert errors == len(records) == 1
 
 
+def test_validate_array_items():
+    with pytest.warns(UserWarning) as records:
+        errors = validate('array_items', allow_invalid={'/properties/allow'})
+
+    assert sorted(str(record.message) for record in records) == [
+        t('tests/fixtures/schema/array_items.json is missing "items" at /properties/fail'),
+    ]
+    assert errors == len(records) == 1
+
+
 def test_validate_items_type():
     with pytest.warns(UserWarning) as records:
         errors = validate('items_type', additional_valid_types=['boolean'],
@@ -226,10 +237,13 @@ def test_validate_object_id():
 
 def test_validate_ref_pass():
     filepath = os.path.join('schema', 'schema.json')
-    with pytest.warns(None) as records:
+
+    with warnings.catch_warnings():
+        warnings.simplefilter('error')  # no warnings
+
         errors = validate_ref(path(filepath), parse(filepath))
 
-    assert errors == len(records) == 0
+    assert errors == 0
 
 
 def test_validate_ref_fail():
